@@ -4,7 +4,8 @@ import React from 'react';
 
 import { getAllPlansButCurrent } from '../../selectors/plans';
 import { getCurrentStack,
-         getCurrentStackDeploymentProgress } from '../../selectors/stacks';
+         getCurrentStackDeploymentProgress,
+         getCurrentStackDeploymentInProgress } from '../../selectors/stacks';
 import { getAvailableNodes, getUnassignedAvailableNodes } from '../../selectors/nodes';
 import { getEnvironmentConfigurationSummary } from '../../selectors/environmentConfiguration';
 import { getCurrentPlan } from '../../selectors/plans';
@@ -29,6 +30,27 @@ class DeploymentPlan extends React.Component {
     this.props.fetchStacks();
   }
 
+  componentWillReceiveProps(nextProps) {
+    if (!nextProps.stacksLoaded) { this.props.fetchStacks(); }
+    this.pollCurrentStack(nextProps.currentStack);
+  }
+
+  componentWillUnmount() {
+    clearTimeout(this.stackProgressTimeout);
+  }
+
+  pollCurrentStack(currentStack) {
+    if (currentStack) {
+      if (currentStack.stack_status.match(/PROGRESS/)) {
+        clearTimeout(this.stackProgressTimeout);
+        this.stackProgressTimeout = setTimeout(() => {
+          this.props.fetchStacks();
+          this.props.fetchStackResources(currentStack);
+        }, 20000);
+      }
+    }
+  }
+
   render() {
     let children;
     // Render children only when current plan is already selected
@@ -52,11 +74,11 @@ class DeploymentPlan extends React.Component {
             </div>
             <ol className="deployment-step-list">
               <DeploymentPlanStep title="Prepare Hardware"
-                                  disabled={this.props.currentStackDeploymentProgress}>
+                                  disabled={this.props.currentStackDeploymentInProgress}>
                 <HardwareStep />
               </DeploymentPlanStep>
               <DeploymentPlanStep title="Specify Deployment Configuration"
-                                  disabled={this.props.currentStackDeploymentProgress}>
+                                  disabled={this.props.currentStackDeploymentInProgress}>
                 <ConfigurePlanStep
                   fetchEnvironmentConfiguration={this.props.fetchEnvironmentConfiguration}
                   summary={this.props.environmentConfigurationSummary}
@@ -65,7 +87,7 @@ class DeploymentPlan extends React.Component {
                   loaded={this.props.environmentConfigurationLoaded}/>
               </DeploymentPlanStep>
               <DeploymentPlanStep title="Configure Roles and Assign Nodes"
-                                  disabled={this.props.currentStackDeploymentProgress}>
+                                  disabled={this.props.currentStackDeploymentInProgress}>
                 <RolesStep availableNodes={this.props.availableNodes}
                            fetchNodes={this.props.fetchNodes}
                            fetchRoles={this.props.fetchRoles}
@@ -76,10 +98,18 @@ class DeploymentPlan extends React.Component {
                            unassignedAvailableNodes={this.props.unassignedAvailableNodes}/>
               </DeploymentPlanStep>
               <DeploymentPlanStep title="Deploy">
-                <DeployStep currentPlan={this.props.currentPlan}
-                            currentStack={this.props.currentStack}
-                            deployPlan={this.props.deployPlan}
-                            fetchStacks={this.props.fetchStacks}/>
+                <DeployStep
+                  currentPlan={this.props.currentPlan}
+                  currentStack={this.props.currentStack}
+                  currentStackResources={this.props.currentStackResources}
+                  currentStackResourcesLoaded={this.props.currentStackResourcesLoaded}
+                  currentStackDeploymentProgress={this.props.currentStackDeploymentProgress}
+                  deployPlan={this.props.deployPlan}
+                  fetchStackEnvironment={this.props.fetchStackEnvironment}
+                  fetchStackResource={this.props.fetchStackResource}
+                  runPostDeploymentValidations={
+                    this.props.runPostDeploymentValidations.bind(this.props.currentPlan.name)}
+                  stacksLoaded={this.props.stacksLoaded}/>
               </DeploymentPlanStep>
             </ol>
           </div>
@@ -100,13 +130,19 @@ DeploymentPlan.propTypes = {
   choosePlan: React.PropTypes.func,
   currentPlan: ImmutablePropTypes.record,
   currentStack: ImmutablePropTypes.record,
-  currentStackDeploymentProgress: React.PropTypes.bool,
+  currentStackDeploymentInProgress: React.PropTypes.bool,
+  currentStackDeploymentProgress: React.PropTypes.number.isRequired,
+  currentStackResources: ImmutablePropTypes.map,
+  currentStackResourcesLoaded: React.PropTypes.bool.isRequired,
   deployPlan: React.PropTypes.func,
   environmentConfigurationLoaded: React.PropTypes.bool,
   environmentConfigurationSummary: React.PropTypes.string,
   fetchEnvironmentConfiguration: React.PropTypes.func,
   fetchNodes: React.PropTypes.func,
   fetchRoles: React.PropTypes.func,
+  fetchStackEnvironment: React.PropTypes.func,
+  fetchStackResource: React.PropTypes.func,
+  fetchStackResources: React.PropTypes.func.isRequired,
   fetchStacks: React.PropTypes.func,
   hasPlans: React.PropTypes.bool,
   inactivePlans: ImmutablePropTypes.map,
@@ -117,15 +153,18 @@ DeploymentPlan.propTypes = {
   roles: ImmutablePropTypes.map,
   rolesLoaded: React.PropTypes.bool,
   route: React.PropTypes.object,
-  runValidationStage: React.PropTypes.func,
-  unassignedAvailableNodes: ImmutablePropTypes.map,
-  validationStages: ImmutablePropTypes.map
+  runPostDeploymentValidations: React.PropTypes.func.isRequired,
+  stacksLoaded: React.PropTypes.bool.isRequired,
+  unassignedAvailableNodes: ImmutablePropTypes.map
 };
 
 export function mapStateToProps(state) {
   return {
     currentPlan: getCurrentPlan(state),
     currentStack: getCurrentStack(state),
+    currentStackResources: state.stacks.resources,
+    currentStackResourcesLoaded: state.stacks.resourcesLoaded,
+    currentStackDeploymentInProgress: getCurrentStackDeploymentInProgress(state),
     currentStackDeploymentProgress: getCurrentStackDeploymentProgress(state),
     environmentConfigurationLoaded: state.environmentConfiguration.loaded,
     environmentConfigurationSummary: getEnvironmentConfigurationSummary(state),
@@ -137,8 +176,8 @@ export function mapStateToProps(state) {
     availableNodes: getAvailableNodes(state),
     roles: state.roles.get('roles'),
     rolesLoaded: state.roles.get('loaded'),
-    unassignedAvailableNodes: getUnassignedAvailableNodes(state),
-    validationStages: state.validations.get('validationStages')
+    stacksLoaded: state.stacks.get('isLoaded'),
+    unassignedAvailableNodes: getUnassignedAvailableNodes(state)
   };
 }
 
@@ -146,15 +185,20 @@ function mapDispatchToProps(dispatch) {
   return {
     choosePlan: planName => dispatch(CurrentPlanActions.choosePlan(planName)),
     deployPlan: planName => dispatch(PlanActions.deployPlan(planName)),
+    fetchStackEnvironment: (stack) => dispatch(StacksActions.fetchEnvironment(stack)),
     fetchEnvironmentConfiguration: (planName, parentPath) => {
       dispatch(EnvironmentConfigurationActions.fetchEnvironmentConfiguration(planName, parentPath));
     },
     fetchNodes: () => dispatch(NodesActions.fetchNodes()),
     fetchRoles: () => dispatch(RolesActions.fetchRoles()),
+    fetchStackResources: (stack) =>
+      dispatch(StacksActions.fetchResources(stack.stack_name, stack.id)),
+    fetchStackResource: (stack, resourceName) =>
+      dispatch(StacksActions.fetchResource(stack, resourceName)),
     fetchStacks: () => dispatch(StacksActions.fetchStacks()),
     notify: notification => dispatch(NotificationActions.notify(notification)),
-    runValidationStage: (uuid) => {
-      dispatch(ValidationsActions.runValidationStage(uuid));
+    runPostDeploymentValidations: planName => {
+      dispatch(ValidationsActions.runValidationGroups(['post-deployment'], planName));
     }
   };
 }
